diff --git a/.gitignore b/.gitignore
index 47dca977c..50274f4d9 100644
--- a/.gitignore
+++ b/.gitignore
@@ -50,4 +50,5 @@ web/yarn-error.log
 auditjs.html
 auditpy.txt
 /venv/
-.scannerwork/
\ No newline at end of file
+.scannerwork/
+web/coverage/
\ No newline at end of file
diff --git a/web/karma.conf.js b/web/karma.conf.js
index f41512575..9c42f69b0 100644
--- a/web/karma.conf.js
+++ b/web/karma.conf.js
@@ -23,6 +23,7 @@ module.exports = function (config) {
       'karma-jasmine-html-reporter',
       'karma-source-map-support',
       'karma-sourcemap-loader',
+      'karma-coverage',
       new webpack.SourceMapDevToolPlugin({
         /*
          * filename: null, // if no value is provided the sourcemap is inlined
@@ -52,6 +53,17 @@ module.exports = function (config) {
       'pgadmin/static/bundle/slickgrid.js': ['webpack', 'sourcemap'],
     },
 
+    // optionally, configure the reporter
+    coverageReporter: {
+      reporters: [
+        // reporters not supporting the `file` property
+        { type: 'html', subdir: 'report-html' },
+        { type: 'lcovonly', subdir: 'report-lcov' },
+      ],
+      dir : 'coverage/',
+      includeAllSources: true,
+    },
+
     webpack: webpackConfig,
     webpackMiddleware: {
       stats: 'errors-only',
diff --git a/web/package.json b/web/package.json
index 71147404a..0dabdcef3 100644
--- a/web/package.json
+++ b/web/package.json
@@ -19,7 +19,7 @@
     "enzyme": "^3.11.0",
     "enzyme-adapter-react-16": "^1.15.2",
     "eslint": "5.15.1",
-    "eslint-plugin-react": "^7.20.3",
+    "eslint-plugin-react": "^7.20.5",
     "file-loader": "^3.0.1",
     "iconfont-webpack-plugin": "^4.2.1",
     "image-webpack-loader": "^4.6.0",
@@ -84,10 +84,12 @@
     "immutability-helper": "^3.0.0",
     "imports-loader": "^0.8.0",
     "ip-address": "^5.8.9",
+    "istanbul-instrumenter-loader": "^3.0.1",
     "jquery": "^3.5.1",
     "jquery-contextmenu": "^2.8.0",
     "jquery-ui": "^1.12.1",
     "json-bignumber": "^1.0.1",
+    "karma-coverage": "^2.0.3",
     "leaflet": "^1.5.1",
     "moment": "^2.24.0",
     "moment-timezone": "^0.5.23",
@@ -118,6 +120,8 @@
     "bundle": "cross-env NODE_ENV=production yarn run bundle:dev",
     "test:karma-once": "yarn run linter && yarn run karma start --single-run",
     "test:karma": "yarn run linter && yarn run karma start",
+    "test:karma-coverage": "yarn run linter && yarn run karma start --reporters coverage,progress",
+    "test:karma-coverage-once": "yarn run linter && yarn run karma start --single-run --reporters coverage,progress",
     "test:feature": "yarn run bundle && python regression/runtests.py --pkg feature_tests",
     "test": "yarn run test:karma-once && yarn run bundle && python regression/runtests.py",
     "pep8": "pycodestyle --config=../.pycodestyle ../docs && pycodestyle --config=../.pycodestyle ../pkg && pycodestyle --config=../.pycodestyle ../tools && pycodestyle --config=../.pycodestyle ../web",
diff --git a/web/webpack.test.config.js b/web/webpack.test.config.js
index 95b280ea1..ba6f99d6b 100644
--- a/web/webpack.test.config.js
+++ b/web/webpack.test.config.js
@@ -65,7 +65,17 @@ module.exports = {
         ',jquery.event.drag' +
         '!exports-loader?' +
         'Slick',
-      }],
+      },
+      {
+        test: /\.js$|\.jsx$/,
+        use: {
+          loader: 'istanbul-instrumenter-loader',
+          options: { esModules: true },
+        },
+        enforce: 'post',
+        exclude: /node_modules|slickgrid|plugins|bundle|generated|regression|[Tt]est.js|[Ss]pecs.js|[Ss]pec.js|\.spec\.js$/,
+      },
+    ],
   },
 
   resolve: {
